==> valentina_0.7.52~dfsg.orig.tar.xz: valentina-v0.7.52/src/libs/vgeometry/vcubicbezierpath_p.h <==
/************************************************************************
 **
 **  @file   vcubicbezierpath_p.h
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   16 3, 2016
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2016 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/

#ifndef VCUBICBEZIERPATH_P_H
#define VCUBICBEZIERPATH_P_H

#include <QSharedData>

#include "vpointf.h"
#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
#include "../vmisc/diagnostic.h"
#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)

QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Weffc++")
QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")

class VCubicBezierPathData final : public QSharedData
{
public:

    VCubicBezierPathData()
        : path()
    {}

    VCubicBezierPathData(const VCubicBezierPathData &splPath)
        : QSharedData(splPath),
          path(splPath.path)
    {}

    virtual ~VCubicBezierPathData();

    /** @brief path list of points. */
    QVector<VPointF> path;

private:
    Q_DISABLE_ASSIGN(VCubicBezierPathData)
};

VCubicBezierPathData::~VCubicBezierPathData()
{}

QT_WARNING_POP

#endif // VCUBICBEZIERPATH_P_H

==> valentina_1.0.0~dfsg.orig.tar.xz: valentina-v1.0.0/src/libs/vgeometry/vcubicbezierpath_p.h <==
/************************************************************************
 **
 **  @file   vcubicbezierpath_p.h
 **  @author Roman Telezhynskyi <dismine(at)gmail.com>
 **  @date   16 3, 2016
 **
 **  @brief
 **  @copyright
 **  This source code is part of the Valentina project, a pattern making
 **  program, whose allow create and modeling patterns of clothing.
 **  Copyright (C) 2016 Valentina project
 **  <https://gitlab.com/smart-pattern/valentina> All Rights Reserved.
 **
 **  Valentina is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation, either version 3 of the License, or
 **  (at your option) any later version.
 **
 **  Valentina is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with Valentina.  If not, see <http://www.gnu.org/licenses/>.
 **
 *************************************************************************/

#ifndef VCUBICBEZIERPATH_P_H
#define VCUBICBEZIERPATH_P_H

#include <QSharedData>

#include "vpointf.h"

QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Weffc++")
QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")

class VCubicBezierPathData final : public QSharedData
{
public:
    VCubicBezierPathData() = default;
    VCubicBezierPathData(const VCubicBezierPathData &splPath) = default;
    ~VCubicBezierPathData() = default;

    /** @brief path list of points. */
    QVector<VPointF> path{}; // NOLINT(misc-non-private-member-variables-in-classes)

private:
    Q_DISABLE_ASSIGN_MOVE(VCubicBezierPathData) // NOLINT
};

QT_WARNING_POP

#endif // VCUBICBEZIERPATH_P_H
